==> v3-pack-center-1.0.1.tgz: package/src/webpack/ComponentWebpack.js <==
const Webpacker = require('./Webpacker');
const path = require('path');
const selfDir = path.resolve(__dirname, '../../components');
const npmRun = require('npm-run');
const fileUtils = require('../utils/FileUtils');

class ComponentWebpack {

    constructor() {
        this.webpacker = new Webpacker();
    }

    pack(src) {
        return new Promise((resolve, reject) => {
            let start = Date.now();
            let promise = this.getWebpackConfig(src);
            promise.then(config=>{
                let step = Date.now();
                console.log(`读取构件webpack配置信息完成，耗时【${step-start}】毫秒！`);
                let promise = this.webpacker.pack(config);
                promise.then(data => {
                    console.log(`构件webpack打包完成，耗时【${Date.now()-step}】毫秒！`);
                    resolve(data);
                }).catch(err => {
                    reject(err);
                });
            }).catch(err => {
                reject(err);
            });
        });
    }

    getWebpackConfig(src) {
        return new Promise((resolve, reject) => {
            try {
                if (src.startsWith(selfDir)) {
                    resolve(require(path.resolve(selfDir, "_default/build/webpack.config.js")));
                } else {
                    let componentMetadata = require(path.resolve(src, "src/components/metadata.json"));
                    let componentCode = componentMetadata[0].code;
                    let distComponentDir = path.resolve(selfDir, componentCode);
                    let v3webpack = require('v3webpack-cli');
                    let commands = ["v3-config",src,distComponentDir];
                    let childProccess = npmRun.exec(commands.join(" "),(err)=>{
                        if(err){
                            reject(err);
                            return;
                        }
                        try{
                            let cfgPath = path.resolve(distComponentDir, "build/webpack.config.js");
                            this.clearCache(distComponentDir);
                            let webpackConfig = require(cfgPath);
                            webpackConfig.context = distComponentDir;
                            webpackConfig.node = {fs:"empty"};
                            //let outputPath = webpackConfig.output.path;
                            //let relativePath = path.relative(distComponentDir,outputPath);
                            //webpackConfig.output.path = path.resolve(src,relativePath);
                            resolve(webpackConfig);
                        }catch(e){
                            reject(e);
                        }
                    });
                    childProccess.stdout.on('data',(data)=>{
                        console.log(data);
                    });
                    childProccess.stderr.on('data',(data)=>{
                        console.log(data);
                    });
                }
            } catch (err) {
                reject(err);
            }
        });

    }

    close() {
        return new Promise((resolve, reject) => {
            let promise = this.webpacker.close();
            promise.then((data) => {
                this.webpacker = null;
                resolve(data);
            }).catch(err => {
                reject(err);
            });
        });
    }

    clearCache(distComponentDir){
        let files = fileUtils.listFiles(distComponentDir,true);
        files.forEach(file => {
            delete require.cache[file];
        });
    }

}

module.exports = ComponentWebpack;

==> v3-pack-center-1.0.8.tgz: package/src/webpack/ComponentWebpack.js <==
const Webpacker = require('./Webpacker');
const path = require('path');
const selfDir = path.resolve(__dirname, '../../components');
const npmRun = require('npm-run');
const fileUtils = require('../utils/FileUtils');
const metdataUtils = require('v3webpack-cli/api/MetadataUtils');

class ComponentWebpack {

    constructor() {
        this.webpacker = new Webpacker();
    }

    pack(src) {
        return new Promise((resolve, reject) => {
            let start = Date.now();
            let promise = this.getWebpackConfig(src);
            promise.then(config=>{
                let step = Date.now();
                console.log(`读取构件webpack配置信息完成，耗时【${step-start}】毫秒！`);
                let promises = [];
                let promise = this.webpacker.pack(config);
                promises.push(promise);
                let componentMetadata = require(path.resolve(src, "src/components/metadata.json"));
                let componentCode = componentMetadata[0].code;
                promise = metdataUtils.genVueMetadata(componentMetadata,path.resolve(selfDir,componentCode));
                promises.push(promise);
                Promise.all(promises).then((datas)=>{
                    let stats = datas[0],vueMetdatas = datas[1];
                    console.log(`构件webpack打包完成，耗时【${Date.now()-step}】毫秒！`);
                    let assets = stats.compilation.assets;
                    let result = [];
                    Object.values(assets).forEach(asset => {
                        result.push(asset.existsAt);
                    });
                    result = result.concat(vueMetdatas);
                    resolve(JSON.stringify(result));
                }).catch(err=>{
                    reject(err);
                });
            }).catch(err => {
                reject(err);
            });
        });
    }

    getWebpackConfig(src) {
        return new Promise((resolve, reject) => {
            try {
                if (src.startsWith(selfDir)) {
                    resolve(require(path.resolve(selfDir, "_default/build/webpack.config.js")));
                } else {
                    let componentMetadata = require(path.resolve(src, "src/components/metadata.json"));
                    let componentCode = componentMetadata[0].code;
                    let distComponentDir = path.resolve(selfDir, componentCode);
                    let configUtils = require('v3webpack-cli/api/ConfigUtils');
                    let promise = configUtils.configOut(src,distComponentDir);
                    promise.then(()=>{
                        try{
                            let cfgPath = path.resolve(distComponentDir, "build/webpack.config.js");
                            this.clearCache(distComponentDir);
                            let webpackConfig = require(cfgPath);
                            webpackConfig.context = distComponentDir;
                            /*webpackConfig.node = {fs:"empty"};
                            let outputPath = webpackConfig.output.path;
                            let relativePath = path.relative(distComponentDir,outputPath);
                            webpackConfig.output.path = path.resolve(src,relativePath);*/
                            resolve(webpackConfig);
                        }catch(e){
                            reject(e);
                        }
                    }).catch(err=>{
                        reject(err);
                    });
                }
            } catch (err) {
                reject(err);
            }
        });

    }

    close() {
        return new Promise((resolve, reject) => {
            let promise = this.webpacker.close();
            promise.then((data) => {
                this.webpacker = null;
                resolve(data);
            }).catch(err => {
                reject(err);
            });
        });
    }

    clearCache(distComponentDir){
        let files = fileUtils.listFiles(distComponentDir,true);
        files.forEach(file => {
            delete require.cache[file];
        });
    }

}

module.exports = ComponentWebpack;
